===============================
langchangetrack
===============================

.. image:: https://badge.fury.io/py/langchangetrack.png
    :target: http://badge.fury.io/py/langchangetrack

.. image:: https://travis-ci.org/viveksck/langchangetrack.png?branch=master
        :target: https://travis-ci.org/viveksck/langchangetrack

.. image:: https://pypip.in/d/langchangetrack/badge.png
        :target: https://pypi.python.org/pypi/langchangetrack


Package for statistically significant language change.

* Free software: BSD license
* Documentation: https://langchangetrack.readthedocs.org.

Features
--------

* This package provides tools to detect linguistic change in a temporal corpora. 
* We do this by capturing linguistic change through different methods. 

Usage
------

    cd examples/distributional/
    ./ngrams_pipeline.sh ../data/temporal_corpus/ ./working/ ./output/ 1900 2000 5 locallinear 100 1000 "ngrams" ../data/temporal_corpus/common_vocab.txt 10

    cd examples/pos
    ./pos_pipeline.sh ../data/temporal_corpus/ ./working/ ./output/ 1900 1930 5 ../data/temporal_corpus/common_vocab.txt 10

    cd examples/freq
    ./freq_pipeline.sh ../data/temporal_corpus/ ./working/ ./output/ 1900 2000 5 ../data/temporal_corpus/common_vocab.txt 10

Requirements
------------
* wheel==0.23.0
* argparse>=1.2.1
* numpy>=0.9.1
* scipy>=0.15.1
* more_itertools>=2.2
* joblib>=0.8.3-r1
* gensim==0.10.3
* statsmodels>=0.5.0
* changepoint>=0.1.0
* nltk>=3.0.0
* textblob>=0.9.0
* textblob-aptagger>=0.2.0

Installation
------------
#. cd langchangetrack
#. pip install -r requirements.txt 
#. python setup.py install

